@@ -132,9 +132,9 @@ class TransferClient(BaseClient):
         ExternalId: str,
         HomeDirectory: str = ...,
         HomeDirectoryType: HomeDirectoryTypeType = ...,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        HomeDirectoryMappings: Sequence[HomeDirectoryMapEntryTypeDef] = ...,
         Policy: str = ...,
-        PosixProfile: "PosixProfileTypeDef" = ...
+        PosixProfile: PosixProfileTypeDef = ...
     ) -> CreateAccessResponseTypeDef:
         """
         Used by administrators to choose which groups in the directory should have
@@ -150,19 +150,19 @@ class TransferClient(BaseClient):
         *,
         Certificate: str = ...,
         Domain: DomainType = ...,
-        EndpointDetails: "EndpointDetailsTypeDef" = ...,
+        EndpointDetails: EndpointDetailsTypeDef = ...,
         EndpointType: EndpointTypeType = ...,
         HostKey: str = ...,
-        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
+        IdentityProviderDetails: IdentityProviderDetailsTypeDef = ...,
         IdentityProviderType: IdentityProviderTypeType = ...,
         LoggingRole: str = ...,
         PostAuthenticationLoginBanner: str = ...,
         PreAuthenticationLoginBanner: str = ...,
         Protocols: Sequence[ProtocolType] = ...,
-        ProtocolDetails: "ProtocolDetailsTypeDef" = ...,
+        ProtocolDetails: ProtocolDetailsTypeDef = ...,
         SecurityPolicyName: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
-        WorkflowDetails: "WorkflowDetailsTypeDef" = ...
+        Tags: Sequence[TagTypeDef] = ...,
+        WorkflowDetails: WorkflowDetailsTypeDef = ...
     ) -> CreateServerResponseTypeDef:
         """
         Instantiates an auto-scaling virtual server based on the selected file transfer
@@ -180,11 +180,11 @@ class TransferClient(BaseClient):
         UserName: str,
         HomeDirectory: str = ...,
         HomeDirectoryType: HomeDirectoryTypeType = ...,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        HomeDirectoryMappings: Sequence[HomeDirectoryMapEntryTypeDef] = ...,
         Policy: str = ...,
-        PosixProfile: "PosixProfileTypeDef" = ...,
+        PosixProfile: PosixProfileTypeDef = ...,
         SshPublicKeyBody: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateUserResponseTypeDef:
         """
         Creates a user and associates them with an existing file transfer protocol-
@@ -197,10 +197,10 @@ class TransferClient(BaseClient):
     def create_workflow(
         self,
         *,
-        Steps: Sequence["WorkflowStepTypeDef"],
+        Steps: Sequence[WorkflowStepTypeDef],
         Description: str = ...,
-        OnExceptionSteps: Sequence["WorkflowStepTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        OnExceptionSteps: Sequence[WorkflowStepTypeDef] = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateWorkflowResponseTypeDef:
         """
         Allows you to create a workflow with specified steps and step details the
@@ -437,7 +437,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#stop_server)
         """
 
-    def tag_resource(self, *, Arn: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def tag_resource(self, *, Arn: str, Tags: Sequence[TagTypeDef]) -> None:
         """
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
@@ -480,9 +480,9 @@ class TransferClient(BaseClient):
         ExternalId: str,
         HomeDirectory: str = ...,
         HomeDirectoryType: HomeDirectoryTypeType = ...,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        HomeDirectoryMappings: Sequence[HomeDirectoryMapEntryTypeDef] = ...,
         Policy: str = ...,
-        PosixProfile: "PosixProfileTypeDef" = ...,
+        PosixProfile: PosixProfileTypeDef = ...,
         Role: str = ...
     ) -> UpdateAccessResponseTypeDef:
         """
@@ -498,17 +498,17 @@ class TransferClient(BaseClient):
         *,
         ServerId: str,
         Certificate: str = ...,
-        ProtocolDetails: "ProtocolDetailsTypeDef" = ...,
-        EndpointDetails: "EndpointDetailsTypeDef" = ...,
+        ProtocolDetails: ProtocolDetailsTypeDef = ...,
+        EndpointDetails: EndpointDetailsTypeDef = ...,
         EndpointType: EndpointTypeType = ...,
         HostKey: str = ...,
-        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
+        IdentityProviderDetails: IdentityProviderDetailsTypeDef = ...,
         LoggingRole: str = ...,
         PostAuthenticationLoginBanner: str = ...,
         PreAuthenticationLoginBanner: str = ...,
         Protocols: Sequence[ProtocolType] = ...,
         SecurityPolicyName: str = ...,
-        WorkflowDetails: "WorkflowDetailsTypeDef" = ...
+        WorkflowDetails: WorkflowDetailsTypeDef = ...
     ) -> UpdateServerResponseTypeDef:
         """
         Updates the file transfer protocol-enabled server's properties after that server
@@ -525,9 +525,9 @@ class TransferClient(BaseClient):
         UserName: str,
         HomeDirectory: str = ...,
         HomeDirectoryType: HomeDirectoryTypeType = ...,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        HomeDirectoryMappings: Sequence[HomeDirectoryMapEntryTypeDef] = ...,
         Policy: str = ...,
-        PosixProfile: "PosixProfileTypeDef" = ...,
+        PosixProfile: PosixProfileTypeDef = ...,
         Role: str = ...
     ) -> UpdateUserResponseTypeDef:
         """
