@@ -38,6 +38,7 @@ __all__ = (
     "ProtocolType",
     "ServerOfflineWaiterName",
     "ServerOnlineWaiterName",
+    "SetStatOptionType",
     "StateType",
     "TlsSessionResumptionModeType",
     "WorkflowStepTypeType",
@@ -79,6 +80,7 @@ OverwriteExistingType = Literal["FALSE", "TRUE"]
 ProtocolType = Literal["FTP", "FTPS", "SFTP"]
 ServerOfflineWaiterName = Literal["server_offline"]
 ServerOnlineWaiterName = Literal["server_online"]
+SetStatOptionType = Literal["DEFAULT", "ENABLE_NO_OP"]
 StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING", "STOP_FAILED"]
 TlsSessionResumptionModeType = Literal["DISABLED", "ENABLED", "ENFORCED"]
 WorkflowStepTypeType = Literal["COPY", "CUSTOM", "DELETE", "TAG"]
