@@ -75,7 +75,7 @@ class ListAccessesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ServerId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ServerId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccessesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListAccesses.paginate)
@@ -90,7 +90,7 @@ class ListExecutionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, WorkflowId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, WorkflowId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListExecutionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListExecutions.paginate)
@@ -105,7 +105,7 @@ class ListSecurityPoliciesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSecurityPoliciesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListSecurityPolicies.paginate)
@@ -120,7 +120,7 @@ class ListServersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
@@ -135,7 +135,7 @@ class ListTagsForResourcePaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Arn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Arn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTagsForResourceResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListTagsForResource.paginate)
@@ -150,7 +150,7 @@ class ListUsersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ServerId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ServerId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListUsersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListUsers.paginate)
@@ -165,7 +165,7 @@ class ListWorkflowsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListWorkflowsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Paginator.ListWorkflows.paginate)
